/*
 * shohaku Copyright (C) 2005 tomoya nagatani
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General
 * Public License as published by the Free Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this library; if not, write to
 * the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package shohaku.core.util.cel;

import java.util.regex.Pattern;

import shohaku.core.collections.Parameters;

/**
 * 正規表現パターンを生成する式を提供します。
 */
public class RegexPatternExpression implements Expression {

    /* この式のリテラル文字を定義します。 */
    private static final Literal[] literals = new Literal[] { new Literal('/', '/') };

    /**
     * リテラル文字 '/', '/' を返します。
     * 
     * @return リテラル文字
     */
    public Literal[] getLiteral() {
        return literals;
    }

    /**
     * 式を実行して値を返します。
     * 
     * @param binder
     *            処理基のバインダー
     * @param literal
     *            リテラル文字
     * @param expression
     *            式
     * @param begin
     *            開始インデックス
     * @param end
     *            終了インデックス
     * @param values
     *            引数値の一覧
     * @return 式の結果
     */
    public Object execute(CELBinder binder, Literal literal, String expression,
            int begin, int end, Parameters values) {
        return Pattern.compile(expression.substring(begin, end));
    }

    public int findNextIndex(CELBinder binder, Literal literal, String expression, int begin) {
        int end = (begin + 1);//'/'.length() == 1
        while (end < expression.length()) {
            end = expression.indexOf('/', end);
            if (-1 == end) {
                return -1;
            }
            if (0 == end || (0 < end && '\\' != expression.charAt(end - 1))) {
                break;
            }
            end++;
        }
        return (end + 1);//end to next
    }
}